#
# spec file for package unshield
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname lib%{name}%{sover}
Name:           unshield
Version:        1.5.1
Release:        2.3
Summary:        A Program to Extract InstallShield Cabinet Files
License:        MIT
URL:            https://github.com/twogood/unshield
Source0:        https://github.com/twogood/unshield/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM armv7l-fpic.patch matwey.kornilov@gmail.com -- fix armv7l build
Patch1:         armv7l-fpic.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
Cabinet (.CAB) files are a form of archive, which is used by the
InstallShield installer software. The unshield program simply unpacks
such files. This is the binary executable.

%package -n %{libname}
Summary:        A Program to Extract InstallShield Cabinet Files

%description -n %{libname}
Cabinet (.CAB) files are a form of archive, which is used by the
InstallShield installer software. The unshield program simply unpacks
such files. This is the shared library.

%package devel
Summary:        Header files, libraries and development documentation for %{libname}
Requires:       %{libname} = %{version}
Provides:       lib%{name} = %{version}
Obsoletes:      lib%{name} < %{version}

%description devel
This package contains the header files, static libraries and development
documentation for %{libname}. If you like to develop programs using %{libname},
you will need to install %{name}-devel.

%prep
%autosetup -p0

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{sover}*

%files devel
%{_includedir}/lib%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Dec  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1
  * Fix library versioning and configure version in CMake
- Update to version 1.5.0
  * Support external files with old compression
  * Honour -O (old compression) flag for t (test) command
  * fix: unshield_utf16_to_utf8 buffer too small for
    U+0800-U+FFFF chars
  * Support for .cab files > 2GB
- Update patch:
  * armv7l-fpic.patch
* Wed Oct  2 2019 Martin Pluskal <mpluskal@suse.com>
- Fix typo in macro
* Mon Aug 26 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.4.3:
  * This release should also improve portability for Microsoft
    Windows.
* Thu May 11 2017 mpluskal@suse.com
- Update to version 1.4.2:
  * exit run-tests.sh with non-zero if there were failed tests
- Changes for 1.4.1:
  * Security and distro fixes
- Changes for 1.4.0:
  * Including fix for CVE-2015-1386 (boo#915181)
- Drop upstreamed patch:
  * libconvert_utf_static.patch
- Some packaging cleanups
* Tue Jun  7 2016 matwey.kornilov@gmail.com
- Add armv7l-fpic.patch: fix armv7l build issue:
  convert_utf/libconvert_utf.a(ConvertUTF.c.o):
  relocation R_ARM_MOVW_ABS_NC against `a local symbol' can not be
  used when making a shared object
* Mon Jul  6 2015 mpluskal@suse.com
- Update to 1.3
  * move build system cmake
- Add libconvert_utf_static.patch
- Drop unnecessary patches
  * unshield-zlib_test.patch
  * unshield-0.6-allow_ruu_extract.patch
* Fri Mar 13 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
- Update dependencies
- Do not install .la file
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Aug  3 2011 andrea@opensuse.org
- added unshield-0.6-allow_ruu_extract.patch to allow extraction
  of some exe files like HTC RUUs
* Wed Jan  5 2011 tejas.guruswamy@opensuse.org
- Fix provides/obsoletes for proper upgrade path
* Sun May  2 2010 masterpatricko@gmail.com
- BuildRequires pkgconfig
* Fri Dec  4 2009 masterpatricko@gmail.com
- Recreate zlib_test.patch to remove fuzz
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sat Jul 18 2009 masterpatricko@gmail.com
- Update to 0.6
  * Fixes to the command line tool
* Tue Jan 29 2008 pth@suse.de
- Enable prototypes.
* Thu Dec 27 2007 crrodriguez@suse.de
- fix library-without-ldconfig-post* errors
- remove static libraries and "la" files
- fix -devel package dependencies
* Mon Mar 12 2007 pth@suse.de
- Initial package creation
